@@ -5,6 +5,7 @@
  */
 
 #include <QApplication>
+#include <QIcon>
 #include <QPointer>
 #include <QProcess>
 #include <QQuickStyle>
@@ -21,7 +22,6 @@
 #endif
 
 #include <KAboutData>
-#include <KCMultiDialog>
 #include <KColorSchemeManager>
 #include <KCrash>
 #include <KDBusService>
@@ -36,6 +36,7 @@
 #include <dbushelper.h>
 
 #include "indicatorhelper.h"
+#include "openconfig.h"
 
 int main(int argc, char **argv)
 {
@@ -47,26 +48,34 @@ int main(int argc, char **argv)
     }
 #endif
 
-    QIcon::setFallbackThemeName(QStringLiteral("breeze"));
-
     QApplication app(argc, argv);
 
     IndicatorHelper helper;
     helper.startDaemon();
 
-    KAboutData about(QStringLiteral("kdeconnect-indicator"),
-                     i18n("KDE Connect Indicator"),
-                     QStringLiteral(KDECONNECT_VERSION_STRING),
-                     i18n("KDE Connect Indicator tool"),
-                     KAboutLicense::GPL,
-                     i18n("(C) 2016 Aleix Pol Gonzalez"));
-    KAboutData::setApplicationData(about);
+    KAboutData aboutData(QStringLiteral("kdeconnect-indicator"),
+                         i18n("KDE Connect Indicator"),
+                         QStringLiteral(KDECONNECT_VERSION_STRING),
+                         i18n("KDE Connect Indicator tool"),
+                         KAboutLicense::GPL,
+                         i18n("© 2016–2025 KDE Connect Team"));
+    aboutData.addAuthor(i18n("Aleix Pol Gonzalez"), {}, QStringLiteral("aleixpol@kde.org"));
+    aboutData.addAuthor(i18n("Albert Vaca Cintora"), {}, QStringLiteral("albertvaka@kde.org"));
+    aboutData.setProgramLogo(QIcon::fromTheme(QStringLiteral("kdeconnect")));
+    KAboutData::setApplicationData(aboutData);
 
-    KCrash::initialize();
-
-#ifdef Q_OS_WIN
+#if defined(Q_OS_WIN) || defined(Q_OS_MAC)
+    // Ensure we have a suitable color theme set for light/dark mode. KColorSchemeManager implicitly applies
+    // a suitable default theme.
     KColorSchemeManager::instance();
+    // Force breeze style to ensure coloring works consistently in dark mode. Specifically tab colors have
+    // troubles on windows.
     QApplication::setStyle(QStringLiteral("breeze"));
+    // Force breeze icon theme to ensure we can correctly adapt icons to color changes WRT dark/light mode.
+    // Without this we may end up with hicolor and fail to support icon recoloring.
+    QIcon::setThemeName(QStringLiteral("breeze"));
+#else
+    QIcon::setFallbackThemeName(QStringLiteral("breeze"));
 #endif
 
     // Default to org.kde.desktop style unless the user forces another style
@@ -74,10 +83,9 @@ int main(int argc, char **argv)
         QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
     }
 
-    KDBusService dbusService(KDBusService::Unique);
+    KCrash::initialize();
 
-    // Trigger loading the KIconLoader plugin
-    about.setProgramLogo(QIcon(QStringLiteral(":/icons/kdeconnect/kdeconnect.svg")));
+    KDBusService dbusService(KDBusService::Unique);
 
     DevicesModel model;
     model.setDisplayFilter(DevicesModel::Reachable | DevicesModel::Paired);
@@ -85,24 +93,14 @@ int main(int argc, char **argv)
     proxyModel.setSourceModel(&model);
     QMenu *menu = new QMenu;
 
-    QPointer<KCMultiDialog> dialog;
-
     DaemonDbusInterface iface;
 
-    auto refreshMenu = [&iface, &proxyModel, &menu, &dialog]() {
+    auto refreshMenu = [&iface, &proxyModel, &menu]() {
         menu->clear();
-        auto configure = menu->addAction(QIcon::fromTheme(QStringLiteral("configure")), i18n("Configure..."));
-        QObject::connect(configure, &QAction::triggered, configure, [&dialog]() {
-            if (dialog == nullptr) {
-                dialog = new KCMultiDialog;
-                dialog->addModule(KPluginMetaData(QStringLiteral("plasma/kcms/systemsettings_qwidgets/kcm_kdeconnect")));
-                dialog->setAttribute(Qt::WA_DeleteOnClose);
-                dialog->show();
-                dialog->raise();
-            } else {
-                dialog->raise();
-                dialog->activateWindow();
-            }
+        // Note: This is needed on macOS since a single click on the icon doesn't open the app like on other platforms.
+        menu->addAction(i18n("Open app"), []() {
+            OpenConfig oc;
+            oc.openConfiguration();
         });
         for (int i = 0, count = proxyModel.rowCount(); i < count; ++i) {
             QObject *deviceObject = proxyModel.data(proxyModel.index(i, 0), DevicesModel::DeviceRole).value<QObject *>();
@@ -127,7 +125,7 @@ int main(int argc, char **argv)
             }
         }
         // Add quit menu
-#if defined Q_OS_MAC
+#if defined(Q_OS_MAC)
         menu->addAction(i18n("Quit"), []() {
             auto message = QDBusMessage::createMethodCall(QStringLiteral("org.kde.kdeconnect.daemon"),
                                                           QStringLiteral("/MainApplication"),
@@ -136,8 +134,7 @@ int main(int argc, char **argv)
             QDBusConnection::sessionBus().call(message, QDBus::NoBlock);
             qApp->quit();
         });
-#elif defined Q_OS_WIN
-
+#elif defined(Q_OS_WIN)
         menu->addAction(QIcon::fromTheme(QStringLiteral("application-exit")), i18n("Quit"), []() {
             qApp->quit();
         });
@@ -161,10 +158,8 @@ int main(int argc, char **argv)
     });
     QObject::connect(&systray, &QSystemTrayIcon::activated, [](QSystemTrayIcon::ActivationReason reason) {
         if (reason == QSystemTrayIcon::Trigger) {
-            const QString kdeconnectAppExecutable = QStandardPaths::findExecutable(QStringLiteral("kdeconnect-app"), {QCoreApplication::applicationDirPath()});
-            if (!kdeconnectAppExecutable.isEmpty()) {
-                QProcess::startDetached(kdeconnectAppExecutable, {});
-            }
+            OpenConfig oc;
+            oc.openConfiguration();
         }
     });
 
